==> flink-1.17.2-src.tgz: flink-1.17.2/flink-runtime-web/web-dashboard/src/app/components/table-aggregated-metrics/table-aggregated-metrics.component.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { DecimalPipe } from '@angular/common';
import { Component, ChangeDetectionStrategy, Input } from '@angular/core';

import { HumanizeBytesPipe } from '@flink-runtime-web/components/humanize-bytes.pipe';
import { HumanizeDurationPipe } from '@flink-runtime-web/components/humanize-duration.pipe';
import { JobVertexAggregated } from '@flink-runtime-web/interfaces';
import { NzTableModule } from 'ng-zorro-antd/table';

@Component({
  selector: 'flink-table-aggregated-metrics',
  templateUrl: './table-aggregated-metrics.component.html',
  styleUrls: ['./table-aggregated-metrics.component.less'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  imports: [NzTableModule, DecimalPipe, HumanizeDurationPipe, HumanizeBytesPipe],
  standalone: true
})
export class TableAggregatedMetricsComponent {
  @Input() isLoading = false;
  @Input() aggregated?: JobVertexAggregated;

  constructor() {}
}

==> flink-1.20.3-src.tgz: flink-1.20.3/flink-runtime-web/web-dashboard/src/app/components/table-aggregated-metrics/table-aggregated-metrics.component.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { DecimalPipe } from '@angular/common';
import { Component, ChangeDetectionStrategy, Input } from '@angular/core';

import { HumanizeBytesPipe } from '@flink-runtime-web/components/humanize-bytes.pipe';
import { HumanizeDurationPipe } from '@flink-runtime-web/components/humanize-duration.pipe';
import { JobVertexAggregated } from '@flink-runtime-web/interfaces';
import { NzTableModule } from 'ng-zorro-antd/table';

@Component({
  selector: 'flink-table-aggregated-metrics',
  templateUrl: './table-aggregated-metrics.component.html',
  styleUrls: ['./table-aggregated-metrics.component.less'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  imports: [NzTableModule, DecimalPipe, HumanizeDurationPipe, HumanizeBytesPipe]
})
export class TableAggregatedMetricsComponent {
  @Input() isLoading = false;
  @Input() aggregated?: JobVertexAggregated;
}
